==> 2.4.11.tar.gz: cloudlog/application/language/turkish/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('Doğrudan komut dosyası erişimine izin verilmez');

$lang['error_no_active_station_profile'] = 'Dikkat: aktif bir istasyon konumu ayarlamanız gerekir.';

$lang['notice_turn_the_radio_on'] = 'Bu gün hiç bir QSO yapmadınız. Telsizi açmanın zamanı geldi!';

$lang['general_word_important'] = 'Önemli';
$lang['general_word_warning'] = 'Warning';
$lang['general_word_danger'] = 'DANGER';
$lang['general_word_maintenance'] = 'Maintenance';
$lang['general_word_info'] = 'Bilgiler';
$lang['general_word_choose_file'] = 'Dosya seç';
$lang['general_word_next'] = 'Next';
$lang['general_word_previous'] = 'Previous';
$lang['general_word_enabled'] = "Enabled";
$lang['general_word_disabled'] = "Disabled";
$lang['general_word_export'] = "Export";
$lang['general_word_import'] = "Import";

$lang['general_word_date'] = 'Tarih';
$lang['general_word_time'] = 'Saat';
$lang['general_word_datetime'] = 'Tarih/Saat';
$lang['general_word_none'] = 'Hiçbiri';
$lang['general_word_name'] = 'İsim';
$lang['general_word_location'] = 'Konum';
$lang['general_word_comment'] = 'Yorum';
$lang['general_word_general'] = 'Genel';
$lang['general_word_satellite'] = 'Uydu';
$lang['general_word_satellite_short'] = 'Uydu';
$lang['general_word_notes'] = 'Notlar';
$lang['general_word_country'] = 'Ülke';
$lang['general_word_city'] = 'City';

$lang['general_word_total'] = 'Toplam';
$lang['general_word_year'] = 'Yıl';
$lang['general_word_month'] = 'Ay';

$lang['general_word_worked'] = 'Çalışılanlar';
$lang['general_word_confirmed'] = 'Onaylanan';
$lang['general_word_needed'] = 'İstenenler';

$lang['general_word_all'] = 'All';
$lang['general_word_no'] = 'Hayır';
$lang['general_word_yes'] = 'Evet';
$lang['general_word_method'] = 'Metod';

$lang['general_word_sent'] = 'Gönderilen';
$lang['general_word_received'] = 'Gelen';
$lang['general_word_requested'] = 'İstenen';
$lang['general_word_queued'] = 'Sıralanan';
$lang['general_word_invalid_ignore'] = 'Geçersiz (Yok say)';
$lang['general_word_qslcard'] = 'QSL Kartı';
$lang['general_word_qslcard_management'] = 'QSL Yönetimi';
$lang['general_word_qslcards'] = 'QSL Kartları';
$lang['general_word_qslcard_direct'] = 'Direk';
$lang['general_word_qslcard_bureau'] = 'Büro';
$lang['general_word_qslcard_electronic'] = 'Elektronik';
$lang['general_word_qslcard_manager'] = 'Yönetici';
$lang['general_word_qslcard_via'] = 'üzerinden';
$lang['general_word_eqslcard'] = 'eQSL Card';
$lang['general_word_eqslcards'] = 'eQSL Kartları';
$lang['general_word_lotw'] = 'Logbook of the World';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_details'] = 'Details';
$lang['general_word_qso_data'] = 'QSO Data';

$lang['general_edit_qso'] = 'QSO değiştirme';
$lang['general_mark_qsl_rx_bureau'] = 'QSL\'i alındı Olarak İşaretle (Ofis)';
$lang['general_mark_qsl_rx_direct'] = 'QSL\'i alındı Olarak İşaretle (Doğrudan)';
$lang['general_mark_qsl_rx_electronic'] = 'QSL\'i alındı Olarak İşaretle (Elektronik)';
$lang['general_mark_qsl_tx_bureau'] = 'QSL\'i Gönderildi Olarak İşaretle (Ofis)';
$lang['general_mark_qsl_tx_direct'] = 'QSL\'i Gönderildi Olarak İşaretle (Doğrudan)';
$lang['general_mark_qsl_requested'] = 'QSL\'i gerektiği gibi işaretleyin';
$lang['general_mark_qsl_requested_bureau'] = 'QSL\'i gerektiği gibi işaretleyin';
$lang['general_mark_qsl_requested_direct'] = 'QSL\'i gerektiği gibi işaretleyin';
$lang['general_mark_qsl_not_required'] = 'QSL\'i gerekli değil olarak işaretleyin';

$lang['general_delete_qso'] = 'QSO\'yu sil';
$lang['general_more_qso'] = 'More QSOs';

$lang['general_lookup_qrz'] = 'Lookup on QRZ.com';
$lang['general_lookup_hamqth'] = 'Lookup on HamQTH';

$lang['general_total_distance'] = 'Topam mesafe';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = 'Maximum file upload size is ';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'İstasyon Konumu';

// ham radio terms
$lang['gen_hamradio_cq'] = "CQ";
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'İstasyon';

$lang['gen_hamradio_call'] = 'Çağrı';
$lang['gen_hamradio_callsign'] = 'Çagrı kodu';
$lang['gen_hamradio_de'] = 'De';
$lang['gen_hamradio_dx'] = 'Dx';
$lang['gen_hamradio_mode'] = 'Mod';
$lang['gen_hamradio_rst_sent'] = 'Gönderilen';
$lang['gen_hamradio_rst_rcvd'] = 'Alınan';
$lang['gen_hamradio_band'] = 'Bant';
$lang['gen_hamradio_bandgroup'] = "Bandgroup";
$lang['gen_hamradio_band_rx'] = 'Bant (RX)';
$lang['gen_hamradio_frequency'] = 'Frekans';
$lang['gen_hamradio_frequency_rx'] = 'Frekans (RX)';
$lang['gen_hamradio_radio'] = 'Telsiz';
$lang['gen_hamradio_rsts'] = 'RST (G)';
$lang['gen_hamradio_rstr'] = 'RST (A)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'My Refs';
$lang['gen_hamradio_exchange_sent_short'] = 'Exch (G)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Exch (A)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL Msg';
$lang['gen_hamradio_locator'] = 'Konum kodu';
$lang['gen_hamradio_transmit_power'] = 'Yayın Gücü (W)';
$lang['gen_hamradio_propagation_mode'] = 'Yayın Mode';

$lang['gen_hamradio_satellite_name'] = 'Uydu Adı';
$lang['gen_hamradio_satellite_mode'] = 'Uydu Modu';

$lang['gen_hamradio_logbook'] = 'Kayıt defteri';

$lang['gen_hamradio_zones'] = 'Zones';
$lang['gen_hamradio_cq_zone'] = 'CQ Alanı';
$lang['gen_hamradio_itu_zone'] = 'ITU Zone';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Deleted DXCC';
$lang['gen_hamradio_continent'] = 'Continent';
$lang['gen_hamradio_usa_state'] = 'ABD Eyaleti';
$lang['gen_hamradio_county_reference'] = 'ABD İlçesi';
$lang['gen_hamradio_iota_reference'] = 'IOTA Referansı';
$lang['gen_hamradio_sota_reference'] = 'SOTA Referansı';
$lang['gen_hamradio_wwff_reference'] = 'WWFF Referansı';
$lang['gen_hamradio_pota_reference'] = 'POTA Referansı';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'Eyalet';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = 'Pafta';
$lang['gen_hamradio_get_gridsquare'] = 'Get Gridsquare';
$lang['gen_hamradio_distance'] = 'Distance';
$lang['gen_hamradio_operator'] = 'Operatör';

$lang['gen_hamradio_sig'] = 'İmza';
$lang['gen_hamradio_sig_info'] = 'İmza bilgisi';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq_part1'] = "If you don't know your CQ Zone then ";
$lang['gen_find_zone_itu_part1'] = "If you don't know your ITU Zone then ";
$lang['gen_find_zone_part2'] = 'click here';
$lang['gen_find_zone_part3'] = ' to find it!';

// Dashboard Words
$lang['dashboard_you_have_had'] = 'Bu gün';
$lang['dashboard_qsos_today'] = 'QSO Yaptınız!';
$lang['dashboard_qso_breakdown'] = 'QSO\'ların Analizi';
$lang['dashboard_countries_breakdown'] = 'Ülke Analizi';
$lang['gen_to_date'] = 'To date';

$lang['gen_from_date'] = 'Tarihten itibaren';

$lang['gen_this_qso_was_confirmed_on'] = 'Bu QSO\'nun onaylandığı tarih';

$lang['error_no_logbook_found'] = 'Kayıt defteri bulunamadı. İstasyon Kayıt Defterleri altında bir kayıt defteri tanızlamanız lazım! Buradan yapın:';

$lang['copy_to_clipboard'] = 'Panoya kopyala';

$lang['africa'] = 'Africa';
$lang['antarctica'] = 'Antarctica';
$lang['asia'] = 'Asia';
$lang['europe'] = 'Europe';
$lang['northamerica'] = 'North America';
$lang['oceania'] = 'Oceania';
$lang['southamerica'] = 'South America';

$lang['gen_band_selection'] = 'Band selection';
$lang['general_word_today'] = 'Today';

==> 2.5.2.tar.gz: cloudlog/application/language/turkish/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('Doğrudan komut dosyası erişimine izin verilmez');

$lang['error_no_active_station_profile'] = 'Dikkat: aktif bir istasyon konumu ayarlamanız gerekir.';

$lang['notice_turn_the_radio_on'] = 'Bu gün hiç bir QSO yapmadınız. Telsizi açmanın zamanı geldi!';

$lang['general_word_important'] = 'Önemli';
$lang['general_word_warning'] = 'Warning';
$lang['general_word_danger'] = 'DANGER';
$lang['general_word_maintenance'] = 'Maintenance';
$lang['general_word_info'] = 'Bilgiler';
$lang['general_word_choose_file'] = 'Dosya seç';
$lang['general_word_next'] = 'Next';
$lang['general_word_previous'] = 'Previous';
$lang['general_word_cancel'] = "Cancel";
$lang['general_word_ok'] = "OK";
$lang['general_word_attention'] = "Attention";
$lang['general_word_enabled'] = "Enabled";
$lang['general_word_disabled'] = "Disabled";
$lang['general_word_export'] = "Export";
$lang['general_word_import'] = "Import";
$lang['general_word_count'] = "Count";
$lang['general_word_filtering_on'] = "Filtering on";

$lang['general_word_date'] = 'Tarih';
$lang['general_word_startdate'] = "Start Date";
$lang['general_word_enddate'] = "End Date";
$lang['general_word_time'] = 'Saat';
$lang['general_word_time_on'] = 'Time on';
$lang['general_word_time_off'] = 'Time off';
$lang['general_word_datetime'] = 'Tarih/Saat';
$lang['general_word_none'] = 'Hiçbiri';
$lang['general_word_name'] = 'İsim';
$lang['general_word_location'] = 'Konum';
$lang['general_word_comment'] = 'Yorum';
$lang['general_word_general'] = 'Genel';
$lang['general_word_satellite'] = 'Uydu';
$lang['general_word_satellite_short'] = 'Uydu';
$lang['general_word_notes'] = 'Notlar';
$lang['general_word_country'] = 'Ülke';
$lang['general_word_city'] = 'City';

$lang['general_word_total'] = 'Toplam';
$lang['general_word_year'] = 'Yıl';
$lang['general_word_month'] = 'Ay';

$lang['general_word_colors'] = "Colors";
$lang['general_word_light'] = "Light/Laser";
$lang['general_word_worked'] = 'Çalışılanlar';
$lang['general_word_worked_not_confirmed'] = "Worked not confirmed";
$lang['general_word_not_worked'] = "Not worked";
$lang['general_word_confirmed'] = 'Onaylanan';
$lang['general_word_confirmation'] = "Confirmation";
$lang['general_word_needed'] = 'İstenenler';

$lang['general_word_all'] = 'All';
$lang['general_word_no'] = 'Hayır';
$lang['general_word_yes'] = 'Evet';
$lang['general_word_method'] = 'Metod';

$lang['general_word_sent'] = 'Gönderilen';
$lang['general_word_received'] = 'Gelen';
$lang['general_word_requested'] = 'İstenen';
$lang['general_word_queued'] = 'Sıralanan';
$lang['general_word_table'] = "Table";
$lang['general_word_invalid_ignore'] = 'Geçersiz (Yok say)';
$lang['general_word_qslcard'] = 'QSL Kartı';
$lang['general_word_qslcard_management'] = 'QSL Yönetimi';
$lang['general_word_qslcards'] = 'QSL Kartları';
$lang['general_word_qslcard_direct'] = 'Direk';
$lang['general_word_qslcard_bureau'] = 'Büro';
$lang['general_word_qslcard_electronic'] = 'Elektronik';
$lang['general_word_qslcard_manager'] = 'Yönetici';
$lang['general_word_qslcard_via'] = 'üzerinden';
$lang['general_word_eqslcard'] = 'eQSL Card';
$lang['general_word_eqslcards'] = 'eQSL Kartları';
$lang['general_word_lotw'] = 'Logbook of the World';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_details'] = 'Details';
$lang['general_word_qso_data'] = 'QSO Data';

$lang['general_edit_qso'] = 'QSO değiştirme';
$lang['general_mark_qsl_rx_bureau'] = 'QSL\'i alındı Olarak İşaretle (Ofis)';
$lang['general_mark_qsl_rx_direct'] = 'QSL\'i alındı Olarak İşaretle (Doğrudan)';
$lang['general_mark_qsl_rx_electronic'] = 'QSL\'i alındı Olarak İşaretle (Elektronik)';
$lang['general_mark_qsl_tx_bureau'] = 'QSL\'i Gönderildi Olarak İşaretle (Ofis)';
$lang['general_mark_qsl_tx_direct'] = 'QSL\'i Gönderildi Olarak İşaretle (Doğrudan)';
$lang['general_mark_qsl_requested'] = 'QSL\'i gerektiği gibi işaretleyin';
$lang['general_mark_qsl_requested_bureau'] = 'QSL\'i gerektiği gibi işaretleyin';
$lang['general_mark_qsl_requested_direct'] = 'QSL\'i gerektiği gibi işaretleyin';
$lang['general_mark_qsl_not_required'] = 'QSL\'i gerekli değil olarak işaretleyin';

$lang['general_delete_qso'] = 'QSO\'yu sil';
$lang['general_more_qso'] = 'More QSOs';

$lang['general_lookup_qrz'] = 'Lookup on QRZ.com';
$lang['general_lookup_hamqth'] = 'Lookup on HamQTH';

$lang['general_total_distance'] = 'Topam mesafe';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = 'Maximum file upload size is ';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'İstasyon Konumu';

// ham radio terms
$lang['gen_hamradio_cq'] = "CQ";
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'İstasyon';

$lang['gen_hamradio_call'] = 'Çağrı';
$lang['gen_hamradio_callsign'] = 'Çagrı kodu';
$lang['gen_hamradio_prefix'] = "Prefix";
$lang['gen_hamradio_suffix'] = "Suffix";
$lang['gen_hamradio_de'] = 'De';
$lang['gen_hamradio_dx'] = 'Dx';
$lang['gen_hamradio_mode'] = 'Mod';
$lang['gen_hamradio_rst_sent'] = 'Gönderilen';
$lang['gen_hamradio_rst_rcvd'] = 'Alınan';
$lang['gen_hamradio_band'] = 'Bant';
$lang['gen_hamradio_bandgroup'] = "Bandgroup";
$lang['gen_hamradio_band_rx'] = 'Bant (RX)';
$lang['gen_hamradio_frequency'] = 'Frekans';
$lang['gen_hamradio_frequency_rx'] = 'Frekans (RX)';
$lang['gen_hamradio_radio'] = 'Telsiz';
$lang['gen_hamradio_rsts'] = 'RST (G)';
$lang['gen_hamradio_rstr'] = 'RST (A)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'My Refs';
$lang['gen_hamradio_exchange_sent_short'] = 'Exch (G)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Exch (A)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qsltype'] = "QSL Type";
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL Msg';
$lang['gen_hamradio_locator'] = 'Konum kodu';
$lang['gen_hamradio_transmit_power'] = 'Yayın Gücü (W)';
$lang['gen_hamradio_propagation_mode'] = 'Yayın Mode';

$lang['gen_hamradio_satellite_name'] = 'Uydu Adı';
$lang['gen_hamradio_satellite_mode'] = 'Uydu Modu';

$lang['gen_hamradio_logbook'] = 'Kayıt defteri';
$lang['gen_hamradio_award'] = "Award";

$lang['gen_hamradio_zones'] = 'Zones';
$lang['gen_hamradio_cq_zone'] = 'CQ Alanı';
$lang['gen_hamradio_itu_zone'] = 'ITU Zone';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Deleted DXCC';
$lang['gen_hamradio_continent'] = 'Continent';
$lang['gen_hamradio_usa_state'] = 'ABD Eyaleti';
$lang['gen_hamradio_county_reference'] = 'ABD İlçesi';
$lang['gen_hamradio_iota_reference'] = 'IOTA Referansı';
$lang['gen_hamradio_sota_reference'] = 'SOTA Referansı';
$lang['gen_hamradio_wwff_reference'] = 'WWFF Referansı';
$lang['gen_hamradio_pota_reference'] = 'POTA Referansı';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'Eyalet';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = 'Pafta';
$lang['gen_hamradio_get_gridsquare'] = 'Get Gridsquare';
$lang['gen_hamradio_latitude'] = "Latitude";
$lang['gen_hamradio_longitude'] = "Longitude";
$lang['gen_hamradio_bearing'] = "Bearing";
$lang['gen_hamradio_distance'] = 'Distance';
$lang['gen_hamradio_operator'] = 'Operatör';

$lang['gen_hamradio_sig'] = 'İmza';
$lang['gen_hamradio_sig_info'] = 'İmza bilgisi';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq_part1'] = "If you don't know your CQ Zone then";
$lang['gen_find_zone_itu_part1'] = "If you don't know your ITU Zone then";
$lang['gen_find_zone_part2'] = "click here";
$lang['gen_find_zone_part3'] = "to find it!";

// Dashboard Words
$lang['dashboard_you_have_had'] = 'Bu gün';
$lang['dashboard_qsos_today'] = 'QSO Yaptınız!';
$lang['dashboard_qso_breakdown'] = 'QSO\'ların Analizi';
$lang['dashboard_countries_breakdown'] = 'Ülke Analizi';
$lang['gen_to_date'] = 'To date';

$lang['gen_from_date'] = 'Tarihten itibaren';

$lang['gen_this_qso_was_confirmed_on'] = 'Bu QSO\'nun onaylandığı tarih';

$lang['error_no_logbook_found'] = 'Kayıt defteri bulunamadı. İstasyon Kayıt Defterleri altında bir kayıt defteri tanızlamanız lazım! Buradan yapın:';

$lang['copy_to_clipboard'] = 'Panoya kopyala';

$lang['africa'] = 'Africa';
$lang['antarctica'] = 'Antarctica';
$lang['asia'] = 'Asia';
$lang['europe'] = 'Europe';
$lang['northamerica'] = 'North America';
$lang['oceania'] = 'Oceania';
$lang['southamerica'] = 'South America';

$lang['gen_band_selection'] = 'Band selection';
$lang['general_word_today'] = 'Today';

$lang['dashboard_php_version_warning'] = 'You need to upgrade your PHP version. Minimum version is 7.4. Your version is';
$lang['dashboard_country_files_warning'] = 'You need to update country files! Go <a href="'.site_url('update').'">here</a> to do it!';
$lang['dashboard_locations_warning'] = 'You have no station locations. Go <a href="'. site_url('station') . '">here</a> to create it!';
$lang['dashboard_logbooks_warning'] = 'You have no station logbook. Go <a href="'. site_url('logbooks') . '">here</a> to create it!';

$lang['hams_at_no_activations_found'] = 'No upcoming activations found. Please check back later.';
